@@ -1,6 +1,8 @@
 import numpy as np, pandas as pd
 import sys
 
+from requests import request
+
 
 from ..lego.lego import Lego
 from typing import Iterable, Union, Mapping
@@ -25,7 +27,7 @@ class SpreadsheetBase(Lego, GoogleAPI):
 
 	def __init__(self, **kwargs):
 		super().__init__(**kwargs)
-		self._requests:list = []
+		self._requests: list = []
 		self._endpoints = None
 
 	@property
@@ -42,6 +44,10 @@ class SpreadsheetBase(Lego, GoogleAPI):
 	def requests(self) -> list:
 		return self._requests
 
+	@request.setter
+	def request(self, value):
+		self._requests = value
+
 	def format_endpoints(self, match_strings: list) -> dict:
 		endpoints = deepcopy(SHEETS_ENDPOINTS)
 		attrs = dir(self)
@@ -71,6 +77,7 @@ class SpreadsheetBase(Lego, GoogleAPI):
 	) -> dict | None:
 		if len(requests) == 0:
 			requests = self.requests
+			self.requests = []
 
 		if type(requests) != list:
 			requests = [requests]
